@@ -10,7 +10,8 @@ use vars qw(@EXPORT_OK @ISA $VERSION);
 @EXPORT_OK = qw(derivatives constant_interpolate
 		linear_interpolate robust_interpolate);
 @ISA       = qw(Exporter);
-$VERSION   = substr q$Revision: 1.05 $, 10;
+$VERSION   = '1.06';
+$VERSION   = eval $VERSION;
 
 sub derivatives {
   my $X = shift;
@@ -354,10 +355,12 @@ or nothing in a void context.
 
 =head1 AUTHOR
 
-Blair Zajac <bzajac@geostaff.com>.
+Blair Zajac <blair@orcaware.com>.
 
 =head1 COPYRIGHT
 
-Copyright (c) 1998 by Blair Zajac.
+Copyright (C) 1998-2005 Blair Zajac.  All rights reserved.  This
+package is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
 
 =cut
